@@ -223,7 +223,7 @@ brasero_burn_caps_can_blank_real (BraseroBurnCaps *self,
 	if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW)
 	&&  (flags & BRASERO_BURN_FLAG_MULTI)
 	&&  (flags & BRASERO_BURN_FLAG_FAST_BLANK)) {
-		BRASERO_BURN_LOG ("fast media blanking only supported but multisession required for DVDRW");
+		BRASERO_BURN_LOG ("fast media blanking only supported but multisession required for DVD-RW");
 		return BRASERO_BURN_NOT_SUPPORTED;
 	}
 
@@ -866,6 +866,17 @@ brasero_burn_caps_is_session_supported_same_src_dest (BraseroBurnCaps *self,
 			if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
 				continue;
 
+			/* This type of disc cannot be burnt; skip them */
+			if (caps->type.subtype.media & BRASERO_MEDIUM_ROM)
+				continue;
+
+			/* These three types only work with CDs. Skip the rest. */
+			if ((output.subtype.img_format == BRASERO_IMAGE_FORMAT_CDRDAO
+			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CLONE
+			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CUE)
+			&& (caps->type.subtype.media & BRASERO_MEDIUM_CD) == 0)
+				continue;
+
 			/* Make sure this is supported by the drive */
 			if (!brasero_drive_can_write_media (burner, caps->type.subtype.media))
 				continue;
@@ -1488,6 +1499,7 @@ brasero_burn_caps_get_flags_for_medium (BraseroBurnCaps *self,
 					BraseroBurnFlag *compulsory_flags)
 {
 	BraseroBurnResult result;
+	gboolean can_blank = FALSE;
 
 	/* See if medium is supported out of the box */
 	result = brasero_caps_get_flags_for_disc (self,
@@ -1501,17 +1513,15 @@ brasero_burn_caps_get_flags_for_medium (BraseroBurnCaps *self,
 	 * - media can be blanked, it has audio or data and we're not merging
 	 * - media is not formatted and it can be blanked/formatted */
 	if (brasero_burn_caps_can_blank_real (self, media, session_flags) == BRASERO_BURN_OK)
-		(*supported_flags) |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
+		can_blank = TRUE;
 	else if (session_flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE)
 		return BRASERO_BURN_NOT_SUPPORTED;
 
-	if (((*supported_flags) & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) != 0) {
+	if (can_blank) {
+		gboolean first_success;
 		BraseroBurnFlag blank_compulsory = BRASERO_BURN_FLAG_NONE;
 		BraseroBurnFlag blank_supported = BRASERO_BURN_FLAG_NONE;
 
-		/* If BLANK flag is supported then MERGE/APPEND can't be compulsory */
-		(*compulsory_flags) &= ~(BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND);
-
 		/* we reached this point in two cases:
 		 * - if the disc cannot be handled
 		 * - if some flags are not handled
@@ -1531,8 +1541,7 @@ brasero_burn_caps_get_flags_for_medium (BraseroBurnCaps *self,
 
 		/* result here is the result of the first operation, so if it
 		 * failed, BLANK before becomes compulsory. */
-		if (result != BRASERO_BURN_OK)
-			(*compulsory_flags) |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
+		first_success = (result == BRASERO_BURN_OK);
 
 		/* pretends it is blank and formatted to see if it would work.
 		 * If it works then that means that the BLANK_BEFORE_WRITE flag
@@ -1551,18 +1560,34 @@ brasero_burn_caps_get_flags_for_medium (BraseroBurnCaps *self,
 							  compulsory_flags);
 
 		/* if both attempts failed, drop it */
-		if (result != BRASERO_BURN_OK
-		&& (((*compulsory_flags) & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE)))
-			return result;
+		if (result != BRASERO_BURN_OK) {
+			/* See if we entirely failed */
+			if (!first_success)
+				return result;
 
-		/* need to add blanking flags */
-		brasero_burn_caps_get_blanking_flags_real (self,
-							   media,
-							   session_flags,
-							   &blank_supported,
-							   &blank_compulsory);
-		(*supported_flags) |= blank_supported;
-		(*compulsory_flags) |= blank_compulsory;
+			/* we tried with a blank medium but did not 
+			 * succeed. So that means the flags BLANK.
+			 * is not supported */
+		}
+		else {
+			(*supported_flags) |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
+
+			if (!first_success)
+				(*compulsory_flags) |= BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE;
+
+			/* If BLANK flag is supported then MERGE/APPEND can't be compulsory */
+			(*compulsory_flags) &= ~(BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND);
+
+			/* need to add blanking flags */
+			brasero_burn_caps_get_blanking_flags_real (self,
+								   media,
+								   session_flags,
+								   &blank_supported,
+								   &blank_compulsory);
+			(*supported_flags) |= blank_supported;
+			(*compulsory_flags) |= blank_compulsory;
+		}
+		
 	}
 	else if (result != BRASERO_BURN_OK)
 		return result;
@@ -1639,7 +1664,7 @@ brasero_burn_caps_get_flags_same_src_dest (BraseroBurnCaps *self,
 		BraseroBurnResult result;
 		gboolean format_supported;
 
-		/* check this image type is possible given the current flags */
+		/* check if this image type is possible given the current flags */
 		if (format != BRASERO_IMAGE_FORMAT_CLONE
 		&& (session_flags & BRASERO_BURN_FLAG_RAW))
 			continue;
@@ -1673,6 +1698,17 @@ brasero_burn_caps_get_flags_same_src_dest (BraseroBurnCaps *self,
 			if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
 				continue;
 
+			/* This type of disc cannot be burnt; skip them */
+			if (caps->type.subtype.media & BRASERO_MEDIUM_ROM)
+				continue;
+
+			/* These three types only work with CDs. Skip the rest. */
+			if ((output.subtype.img_format == BRASERO_IMAGE_FORMAT_CDRDAO
+			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CLONE
+			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CUE)
+			&& (caps->type.subtype.media & BRASERO_MEDIUM_CD) == 0)
+				continue;
+
 			/* Merge all available flags for each possible medium type */
 			supported = BRASERO_BURN_FLAG_NONE;
 			compulsory = BRASERO_BURN_FLAG_NONE;
@@ -1729,7 +1765,7 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 	gboolean res;
 	BraseroMedia media;
 	BraseroBurnCaps *self;
-	BraseroTrackType input;
+	BraseroTrackType *input;
 	BraseroBurnResult result;
 
 	BraseroBurnFlag session_flags;
@@ -1740,8 +1776,9 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 
 	self = brasero_burn_caps_get_default ();
 
-	brasero_burn_session_get_input_type (session, &input);
-	BRASERO_BURN_LOG_WITH_TYPE (&input,
+	input = brasero_track_type_new ();
+	brasero_burn_session_get_input_type (session, input);
+	BRASERO_BURN_LOG_WITH_TYPE (input,
 				    BRASERO_PLUGIN_IO_NONE,
 				    "FLAGS: searching available flags for input");
 
@@ -1749,7 +1786,7 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 		BRASERO_BURN_LOG ("FLAGS: image required");
 
 		/* In this case no APPEND/MERGE is possible */
-		if (input.type == BRASERO_TRACK_TYPE_DISC)
+		if (brasero_track_type_get_has_medium (input))
 			supported_flags |= BRASERO_BURN_FLAG_EJECT;
 
 		*supported = supported_flags;
@@ -1758,6 +1795,7 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 		BRASERO_BURN_LOG_FLAGS (supported_flags, "FLAGS: supported");
 		BRASERO_BURN_LOG_FLAGS (compulsory_flags, "FLAGS: compulsory");
 
+		brasero_track_type_free (input);
 		g_object_unref (self);
 		return BRASERO_BURN_OK;
 	}
@@ -1788,6 +1826,7 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 		else
 			BRASERO_BURN_LOG ("No available flags for copy");
 
+		brasero_track_type_free (input);
 		g_object_unref (self);
 		return result;
 	}
@@ -1803,12 +1842,14 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 	res = brasero_check_flags_for_drive (brasero_burn_session_get_burner (session), session_flags);
 	if (!res) {
 		BRASERO_BURN_LOG ("Session flags not supported by drive");
+		brasero_track_type_free (input);
 		g_object_unref (self);
 		return BRASERO_BURN_ERR;
 	}
 
 	if ((session_flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
 	&&  (session_flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE)) {
+		brasero_track_type_free (input);
 		g_object_unref (self);
 		return BRASERO_BURN_NOT_SUPPORTED;
 	}
@@ -1818,10 +1859,11 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 	result = brasero_burn_caps_get_flags_for_medium (self,
 							 media,
 							 session_flags,
-							 &input,
+							 input,
 							 &supported_flags,
 							 &compulsory_flags);
 
+	brasero_track_type_free (input);
 	g_object_unref (self);
 
 	if (result != BRASERO_BURN_OK)
