@@ -43,6 +43,8 @@
 #include "brasero-io.h"
 #include "brasero-tags.h"
 
+static BraseroIOJobCallbacks *io_methods = NULL;
+
 typedef struct _BraseroTrackStreamCfgPrivate BraseroTrackStreamCfgPrivate;
 struct _BraseroTrackStreamCfgPrivate
 {
@@ -117,13 +119,29 @@ brasero_track_stream_cfg_results_cb (GObject *obj,
 		return;
 	}
 
+	/* Also make sure it's duration is appropriate (!= 0) */
+	len = g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN);
+	if (len <= 0) {
+		gchar *name;
+
+		BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
+		priv->error = g_error_new (BRASERO_BURN_ERROR,
+					   BRASERO_BURN_ERROR_GENERAL,
+					   /* Translators: %s is the name of the file */
+					   _("\"%s\" is not suitable for audio or video media"),
+					   name);
+		g_free (name);
+
+		brasero_track_changed (BRASERO_TRACK (obj));
+		return;
+	}
+
 	/* FIXME: we don't know whether it's audio or video that is required */
 	if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY) {
 		/* This error is special as it can be recovered from */
 		priv->error = g_error_new (BRASERO_BURN_ERROR,
 					   BRASERO_BURN_ERROR_FILE_FOLDER,
 					   _("Directories cannot be added to video or audio discs"));
-
 		brasero_track_changed (BRASERO_TRACK (obj));
 		return;
 	}
@@ -178,7 +196,6 @@ brasero_track_stream_cfg_results_cb (GObject *obj,
 												BRASERO_METADATA_INFO);
 
 	/* size */
-	len = g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN);
 	if (BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_boundaries)
 		BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_boundaries (BRASERO_TRACK_STREAM (obj),
 												    0,
@@ -280,11 +297,14 @@ brasero_track_stream_cfg_get_info (BraseroTrackStreamCfg *track)
 	}
 
 	/* get info async for the file */
-	if (!priv->load_uri)
-		priv->load_uri = brasero_io_register (G_OBJECT (track),
-						      brasero_track_stream_cfg_results_cb,
-						      NULL,
-						      NULL);
+	if (!priv->load_uri) {
+		if (!io_methods)
+			io_methods = brasero_io_register_job_methods (brasero_track_stream_cfg_results_cb,
+			                                              NULL,
+			                                              NULL);
+
+		priv->load_uri = brasero_io_register_with_methods (G_OBJECT (track), io_methods);
+	}
 
 	priv->loading = TRUE;
 	uri = brasero_track_stream_get_source (BRASERO_TRACK_STREAM (track), TRUE);
@@ -364,7 +384,11 @@ brasero_track_stream_cfg_finalize (GObject *object)
 
 	if (priv->load_uri) {
 		brasero_io_cancel_by_base (priv->load_uri);
-		g_free (priv->load_uri);
+
+		if (io_methods->ref == 1)
+			io_methods = NULL;
+
+		brasero_io_job_base_free (priv->load_uri);
 		priv->load_uri = NULL;
 	}
 
