@@ -55,6 +55,7 @@
 #include "brasero-volume.h"
 #include "brasero-drive.h"
 
+#include "brasero-drive-priv.h"
 #include "scsi-device.h"
 #include "scsi-utils.h"
 #include "scsi-spc1.h"
@@ -72,6 +73,7 @@ struct _BraseroDrivePrivate
 	GThread *probe;
 	GMutex *mutex;
 	GCond *cond;
+	GCond *cond_probe;
 	gint probe_id;
 
 	BraseroMedium *medium;
@@ -86,9 +88,16 @@ struct _BraseroDrivePrivate
 
 	GCancellable *cancel;
 
+	guint initial_probe:1;
+	guint initial_probe_cancelled:1;
+
 	guint probed:1;
 	guint has_medium:1;
 	guint probe_cancelled:1;
+
+	guint locked:1;
+	guint ejecting:1;
+	guint probe_waiting:1;
 };
 
 #define BRASERO_DRIVE_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_DRIVE, BraseroDrivePrivate))
@@ -111,6 +120,9 @@ G_DEFINE_TYPE (BraseroDrive, brasero_drive, G_TYPE_OBJECT);
 
 #define BRASERO_DRIVE_OPEN_ATTEMPTS			5
 
+static void
+brasero_drive_probe_inside (BraseroDrive *drive);
+
 /**
  * brasero_drive_get_gdrive:
  * @drive: a #BraseroDrive
@@ -187,6 +199,56 @@ last_resort:
 	return result;
 }
 
+static void
+brasero_drive_cancel_probing (BraseroDrive *drive)
+{
+	BraseroDrivePrivate *priv;
+
+	priv = BRASERO_DRIVE_PRIVATE (drive);
+
+	priv->probe_waiting = FALSE;
+
+	g_mutex_lock (priv->mutex);
+	if (priv->probe) {
+		/* This to signal that we are cancelling */
+		priv->probe_cancelled = TRUE;
+		priv->initial_probe_cancelled = TRUE;
+
+		/* This is to wake up the thread if it
+		 * was asleep waiting to retry to get
+		 * hold of a handle to probe the drive */
+		g_cond_signal (priv->cond_probe);
+
+		g_cond_wait (priv->cond, priv->mutex);
+	}
+	g_mutex_unlock (priv->mutex);
+
+	priv->probed = TRUE;
+
+	if (priv->probe_id) {
+		g_source_remove (priv->probe_id);
+		priv->probe_id = 0;
+	}
+}
+
+static void
+brasero_drive_wait_probing_thread (BraseroDrive *drive)
+{
+	BraseroDrivePrivate *priv;
+
+	priv = BRASERO_DRIVE_PRIVATE (drive);
+
+	g_mutex_lock (priv->mutex);
+	if (priv->probe) {
+		/* This is to wake up the thread if it
+		 * was asleep waiting to retry to get
+		 * hold of a handle to probe the drive */
+		g_cond_signal (priv->cond_probe);
+		g_cond_wait (priv->cond, priv->mutex);
+	}
+	g_mutex_unlock (priv->mutex);
+}
+
 /**
  * brasero_drive_eject:
  * @drive: #BraseroDrive
@@ -220,12 +282,25 @@ brasero_drive_eject (BraseroDrive *drive,
 
 	BRASERO_MEDIA_LOG ("Trying to eject drive");
 	if (priv->gdrive) {
+		/*Wait for any ongoing probing as it
+		 * would prevent the door from being
+		 * opened. */
+		brasero_drive_wait_probing_thread (drive);
+
+		priv->ejecting = TRUE;
 		res = brasero_gio_operation_eject_drive (priv->gdrive,
 							 priv->cancel,
 							 wait,
 							 error);
+		priv->ejecting = FALSE;
+		if (priv->probe_waiting)
+			brasero_drive_probe_inside (drive);
+
 		if (res)
 			return TRUE;
+
+		if (g_cancellable_is_cancelled (priv->cancel))
+			return FALSE;
 	}
 	else
 		BRASERO_MEDIA_LOG ("No GDrive");
@@ -242,10 +317,21 @@ brasero_drive_eject (BraseroDrive *drive,
 	BRASERO_MEDIA_LOG ("Trying to eject volume");
 	gvolume = brasero_volume_get_gvolume (BRASERO_VOLUME (priv->medium));
 	if (gvolume) {
+		/* Cancel any ongoing probing as it
+		 * would prevent the door from being
+		 * opened. */
+		brasero_drive_wait_probing_thread (drive);
+
+		priv->ejecting = TRUE;
 		res = brasero_gio_operation_eject_volume (gvolume,
 							  priv->cancel,
 							  wait,
 							  error);
+
+		priv->ejecting = FALSE;
+		if (priv->probe_waiting)
+			brasero_drive_probe_inside (drive);
+
 		g_object_unref (gvolume);
 	}
 
@@ -382,13 +468,37 @@ brasero_drive_can_use_exclusively (BraseroDrive *drive)
 	return TRUE;
 }
 
+/**
+ * brasero_drive_is_locked:
+ * @drive: a #BraseroDrive
+ * @reason: a #gchar or NULL. A string to indicate what the drive was locked for if return value is %TRUE
+ *
+ * Checks whether a #BraseroDrive is currently locked. Manual ejection shouldn't be possible any more.
+ *
+ * Since 2.29.0
+ *
+ * Return value: %TRUE if the drive is locked or %FALSE.
+ **/
+gboolean
+brasero_drive_is_locked (BraseroDrive *drive,
+                         gchar **reason)
+{
+	BraseroDrivePrivate *priv;
+
+	g_return_val_if_fail (drive != NULL, FALSE);
+	g_return_val_if_fail (BRASERO_IS_DRIVE (drive), FALSE);
+
+	priv = BRASERO_DRIVE_PRIVATE (drive);
+	return priv->locked;
+}
+
 /**
  * brasero_drive_lock:
  * @drive: a #BraseroDrive
  * @reason: a string to indicate what the drive was locked for
- * @reason_for_failure: a string to hold the reason why the locking failed
+ * @reason_for_failure: a string (or NULL) to hold the reason why the locking failed
  *
- * Locks a #BraseroDrive. Ejection shouldn't be possible any more.
+ * Locks a #BraseroDrive. Manual ejection shouldn't be possible any more.
  *
  * Return value: %TRUE if the drive was successfully locked or %FALSE.
  **/
@@ -415,11 +525,12 @@ brasero_drive_lock (BraseroDrive *drive,
 		return FALSE;
 
 	result = (brasero_sbc_medium_removal (handle, 1, NULL) == BRASERO_SCSI_OK);
-	if (!result) {
-		BRASERO_MEDIA_LOG ("Device failed to lock");
+	if (result) {
+		BRASERO_MEDIA_LOG ("Device locked");
+		priv->locked = TRUE;
 	}
 	else
-		BRASERO_MEDIA_LOG ("Device locked");
+		BRASERO_MEDIA_LOG ("Device failed to lock");
 
 	brasero_device_handle_close (handle);
 	return result;
@@ -454,13 +565,25 @@ brasero_drive_unlock (BraseroDrive *drive)
 		return FALSE;
 
 	result = (brasero_sbc_medium_removal (handle, 0, NULL) == BRASERO_SCSI_OK);
-	if (!result) {
-		BRASERO_MEDIA_LOG ("Device failed to unlock");
+	if (result) {
+		BRASERO_MEDIA_LOG ("Device unlocked");
+		priv->locked = FALSE;
+
+		if (priv->probe_waiting) {
+			BRASERO_MEDIA_LOG ("Probe on hold");
+
+			/* A probe was waiting */
+			priv->probe_waiting = FALSE;
+
+			BRASERO_MEDIA_LOG ("Probe on hold");
+			brasero_drive_probe_inside (drive);
+		}
 	}
 	else
-		BRASERO_MEDIA_LOG ("Device unlocked");
+		BRASERO_MEDIA_LOG ("Device failed to unlock");
 
 	brasero_device_handle_close (handle);
+
 	return result;
 }
 
@@ -762,16 +885,23 @@ brasero_drive_probed_inside (gpointer data)
 	self = BRASERO_DRIVE (data);
 	priv = BRASERO_DRIVE_PRIVATE (self);
 
-	g_mutex_lock (priv->mutex);
+	if (!g_mutex_trylock (priv->mutex))
+		return TRUE;
+
 	priv->probe_id = 0;
 	g_mutex_unlock (priv->mutex);
 
+	priv->probed = TRUE;
+
 	if (priv->has_medium) {
-		if (priv->medium)
+		if (priv->medium) {
+			BRASERO_MEDIA_LOG ("Already a medium. Skipping");
 			return FALSE;
+		}
 
-		BRASERO_MEDIA_LOG ("Medium inserted");
+		BRASERO_MEDIA_LOG ("Probing new medium");
 
+		priv->probed = FALSE;
 		priv->medium = g_object_new (BRASERO_TYPE_VOLUME,
 					     "drive", self,
 					     NULL);
@@ -795,10 +925,7 @@ brasero_drive_probed_inside (gpointer data)
 			       medium);
 
 		g_object_unref (medium);
-		priv->probed = TRUE;
 	}
-	else
-		priv->probed = TRUE;
 
 	return FALSE;
 }
@@ -807,10 +934,11 @@ static gpointer
 brasero_drive_probe_inside_thread (gpointer data)
 {
 	gint counter = 0;
+	GTimeVal wait_time;
 	const gchar *device;
 	BraseroScsiErrCode code;
 	BraseroDrivePrivate *priv;
-	BraseroDeviceHandle *handle;
+	BraseroDeviceHandle *handle = NULL;
 	BraseroDrive *drive = BRASERO_DRIVE (data);
 
 	priv = BRASERO_DRIVE_PRIVATE (drive);
@@ -820,6 +948,8 @@ brasero_drive_probe_inside_thread (gpointer data)
 	device = brasero_drive_get_device (drive);
 	BRASERO_MEDIA_LOG ("Trying to open device %s", device);
 
+	priv->has_medium = FALSE;
+
 	handle = brasero_device_handle_open (device, FALSE, &code);
 	while (!handle && counter <= BRASERO_DRIVE_OPEN_ATTEMPTS) {
 		sleep (1);
@@ -833,13 +963,15 @@ brasero_drive_probe_inside_thread (gpointer data)
 		handle = brasero_device_handle_open (device, FALSE, &code);
 	}
 
-	if (priv->probe_cancelled) {
-		BRASERO_MEDIA_LOG ("Open () cancelled");
+	if (!handle) {
+		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
 		goto end;
 	}
 
-	if (!handle) {
-		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
+	if (priv->probe_cancelled) {
+		BRASERO_MEDIA_LOG ("Open () cancelled");
+
+		brasero_device_handle_close (handle);
 		goto end;
 	}
 
@@ -847,21 +979,30 @@ brasero_drive_probe_inside_thread (gpointer data)
 		if (code == BRASERO_SCSI_NO_MEDIUM) {
 			BRASERO_MEDIA_LOG ("No medium inserted");
 
-			priv->has_medium = FALSE;
+			brasero_device_handle_close (handle);
 			goto end;
 		}
 
 		if (code != BRASERO_SCSI_NOT_READY) {
-			brasero_device_handle_close (handle);
 			BRASERO_MEDIA_LOG ("Device does not respond");
+
+			brasero_device_handle_close (handle);
 			goto end;
 		}
 
-		sleep (2);
+		g_get_current_time (&wait_time);
+		g_time_val_add (&wait_time, 2000000);
+
+		g_mutex_lock (priv->mutex);
+		g_cond_timed_wait (priv->cond_probe,
+		                   priv->mutex,
+		                   &wait_time);
+		g_mutex_unlock (priv->mutex);
 
 		if (priv->probe_cancelled) {
-			brasero_device_handle_close (handle);
 			BRASERO_MEDIA_LOG ("Device probing cancelled");
+
+			brasero_device_handle_close (handle);
 			goto end;
 		}
 	}
@@ -894,27 +1035,30 @@ brasero_drive_probe_inside (BraseroDrive *drive)
 
 	priv = BRASERO_DRIVE_PRIVATE (drive);
 
-	priv->probed = FALSE;
+	if (priv->initial_probe) {
+		BRASERO_MEDIA_LOG ("Still initializing the drive properties");
+		return;
+	}
 
 	/* Check that a probe is not already being performed */
-	g_mutex_lock (priv->mutex);
-	if (!priv->probe) {
-		BRASERO_MEDIA_LOG ("Setting new probe");
-
-		if (priv->probe_id) {
-			/* Remove the result reporting as
-			 * the status seem to have changed */
-			g_source_remove (priv->probe_id);
-			priv->probe_id = 0;
-		}
-
-		priv->probe = g_thread_create (brasero_drive_probe_inside_thread,
-					       drive,
-					       FALSE,
-					       NULL);
-	}
-	else
+	if (priv->probe) {
 		BRASERO_MEDIA_LOG ("Ongoing probe");
+		brasero_drive_cancel_probing (drive);
+	}
+
+	BRASERO_MEDIA_LOG ("Setting new probe");
+
+	g_mutex_lock (priv->mutex);
+
+	priv->probed = FALSE;
+	priv->probe_waiting = FALSE;
+	priv->probe_cancelled = FALSE;
+
+	priv->probe = g_thread_create (brasero_drive_probe_inside_thread,
+	                               drive,
+				       FALSE,
+				       NULL);
+
 	g_mutex_unlock (priv->mutex);
 }
 
@@ -922,6 +1066,24 @@ static void
 brasero_drive_medium_gdrive_changed_cb (BraseroDrive *gdrive,
 					BraseroDrive *drive)
 {
+	BraseroDrivePrivate *priv;
+
+	priv = BRASERO_DRIVE_PRIVATE (drive);
+	if (priv->locked || priv->ejecting) {
+		BRASERO_MEDIA_LOG ("Waiting for next unlocking of the drive to probe");
+
+		/* Since the drive was locked, it should
+		 * not be possible that the medium
+		 * actually changed.
+		 * This allows to avoid probing while
+		 * we are burning something.
+		 * Delay the probe until brasero_drive_unlock ()
+		 * is called.  */
+		priv->probe_waiting = TRUE;
+		return;
+	}
+
+	BRASERO_MEDIA_LOG ("GDrive changed");
 	brasero_drive_probe_inside (drive);
 }
 
@@ -936,7 +1098,12 @@ brasero_drive_update_gdrive (BraseroDrive *drive,
 		g_signal_handlers_disconnect_by_func (priv->gdrive,
 						      brasero_drive_medium_gdrive_changed_cb,
 						      drive);
+
+		/* Stop any ongoing GIO operation */
+		g_cancellable_cancel (priv->cancel);
+	
 		g_object_unref (priv->gdrive);
+		priv->gdrive = NULL;
 	}
 
 	BRASERO_MEDIA_LOG ("Setting GDrive %p", gdrive);
@@ -952,6 +1119,20 @@ brasero_drive_update_gdrive (BraseroDrive *drive,
 				  drive);
 	}
 
+	if (priv->locked || priv->ejecting) {
+		BRASERO_MEDIA_LOG ("Waiting for next unlocking of the drive to probe");
+
+		/* Since the drive was locked, it should
+		 * not be possible that the medium
+		 * actually changed.
+		 * This allows to avoid probing while
+		 * we are burning something.
+		 * Delay the probe until brasero_drive_unlock ()
+		 * is called.  */
+		priv->probe_waiting = TRUE;
+		return;
+	}
+
 	brasero_drive_probe_inside (drive);
 }
 
@@ -982,20 +1163,20 @@ brasero_drive_reprobe (BraseroDrive *drive)
 		g_drive_poll_for_media (priv->gdrive, NULL, NULL, NULL);
 	}
 
-	if (!priv->medium)
-		return;
+	priv->probe_waiting = FALSE;
 
 	BRASERO_MEDIA_LOG ("Reprobing inserted medium");
+	if (priv->medium) {
+		/* remove current medium */
+		medium = priv->medium;
+		priv->medium = NULL;
 
-	/* remove current medium */
-	medium = priv->medium;
-	priv->medium = NULL;
-
-	g_signal_emit (drive,
-		       drive_signals [MEDIUM_REMOVED],
-		       0,
-		       medium);
-	g_object_unref (medium);
+		g_signal_emit (drive,
+			       drive_signals [MEDIUM_REMOVED],
+			       0,
+			       medium);
+		g_object_unref (medium);
+	}
 
 	brasero_drive_probe_inside (drive);
 }
@@ -1007,8 +1188,12 @@ brasero_drive_probed (gpointer data)
 
 	priv = BRASERO_DRIVE_PRIVATE (data);
 
-	g_mutex_lock (priv->mutex);
+	if (!g_mutex_trylock (priv->mutex))
+		return TRUE;
+
+	priv->initial_probe = FALSE;
 	priv->probe_id = 0;
+
 	g_mutex_unlock (priv->mutex);
 
 	brasero_drive_probe_inside (BRASERO_DRIVE (data));
@@ -1090,7 +1275,7 @@ brasero_drive_get_caps_profiles (BraseroDrive *self,
 				break;
 		}
 
-		if (priv->probe_cancelled)
+		if (priv->initial_probe_cancelled)
 			break;
 
 		/* Move the pointer to the next features */
@@ -1143,6 +1328,7 @@ static gpointer
 brasero_drive_probe_thread (gpointer data)
 {
 	gint counter = 0;
+	GTimeVal wait_time;
 	const gchar *device;
 	BraseroScsiResult res;
 	BraseroScsiInquiry hdr;
@@ -1162,7 +1348,7 @@ brasero_drive_probe_thread (gpointer data)
 	while (!handle && counter <= BRASERO_DRIVE_OPEN_ATTEMPTS) {
 		sleep (1);
 
-		if (priv->probe_cancelled) {
+		if (priv->initial_probe_cancelled) {
 			BRASERO_MEDIA_LOG ("Open () cancelled");
 			goto end;
 		}
@@ -1171,7 +1357,7 @@ brasero_drive_probe_thread (gpointer data)
 		handle = brasero_device_handle_open (device, FALSE, &code);
 	}
 
-	if (priv->probe_cancelled) {
+	if (priv->initial_probe_cancelled) {
 		BRASERO_MEDIA_LOG ("Open () cancelled");
 		goto end;
 	}
@@ -1193,9 +1379,16 @@ brasero_drive_probe_thread (gpointer data)
 			goto end;
 		}
 
-		sleep (2);
+		g_get_current_time (&wait_time);
+		g_time_val_add (&wait_time, 2000000);
 
-		if (priv->probe_cancelled) {
+		g_mutex_lock (priv->mutex);
+		g_cond_timed_wait (priv->cond_probe,
+		                   priv->mutex,
+		                   &wait_time);
+		g_mutex_unlock (priv->mutex);
+
+		if (priv->initial_probe_cancelled) {
 			brasero_device_handle_close (handle);
 			BRASERO_MEDIA_LOG ("Device probing cancelled");
 			goto end;
@@ -1244,7 +1437,7 @@ end:
 
 	g_mutex_lock (priv->mutex);
 
-	if (!priv->probe_cancelled)
+	if (!priv->initial_probe_cancelled)
 		priv->probe_id = g_idle_add (brasero_drive_probed, drive);
 
 	priv->probe = NULL;
@@ -1282,10 +1475,13 @@ brasero_drive_init_real_device (BraseroDrive *drive,
 	 * BraseroDrive that exported until it returns PROBED signal.
 	 * One (good) side effect is that it also improves start time. */
 	g_mutex_lock (priv->mutex);
+
+	priv->initial_probe = TRUE;
 	priv->probe = g_thread_create (brasero_drive_probe_thread,
 				       drive,
 				       FALSE,
 				       NULL);
+
 	g_mutex_unlock (priv->mutex);
 }
 
@@ -1367,6 +1563,7 @@ brasero_drive_init (BraseroDrive *object)
 
 	priv->mutex = g_mutex_new ();
 	priv->cond = g_cond_new ();
+	priv->cond_probe = g_cond_new ();
 }
 
 static void
@@ -1378,17 +1575,7 @@ brasero_drive_finalize (GObject *object)
 
 	BRASERO_MEDIA_LOG ("Finalizing BraseroDrive");
 
-	g_mutex_lock (priv->mutex);
-	if (priv->probe) {
-		priv->probe_cancelled = TRUE;
-		g_cond_wait (priv->cond, priv->mutex);
-	}
-	g_mutex_unlock (priv->mutex);
-
-	if (priv->probe_id) {
-		g_source_remove (priv->probe_id);
-		priv->probe_id = 0;
-	}
+	brasero_drive_cancel_probing (BRASERO_DRIVE (object));
 
 	if (priv->mutex) {
 		g_mutex_free (priv->mutex);
@@ -1400,6 +1587,11 @@ brasero_drive_finalize (GObject *object)
 		priv->cond = NULL;
 	}
 
+	if (priv->cond_probe) {
+		g_cond_free (priv->cond_probe);
+		priv->cond_probe = NULL;
+	}
+
 	if (priv->medium) {
 		g_signal_emit (object,
 			       drive_signals [MEDIUM_REMOVED],
