@@ -1,24 +1,28 @@
-/***************************************************************************
- *            cdrdao.c
- *
- *  dim jan 22 15:38:18 2006
- *  Copyright  2006  Rouquier Philippe
- *  brasero-app@wanadoo.fr
- ***************************************************************************/
-
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- *  Brasero is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * Libbrasero-burn
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  *
- *  Brasero is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * Libbrasero-burn is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to:
+ * The Libbrasero-burn authors hereby grant permission for non-GPL compatible
+ * GStreamer plugins to be used and distributed together with GStreamer
+ * and Libbrasero-burn. This permission is above and beyond the permissions granted
+ * by the GPL license by which Libbrasero-burn is covered. If you modify this code
+ * you may extend this exception to your version of the code, but you are not
+ * obligated to do so. If you do not wish to do so, delete this exception
+ * statement from your version.
+ * 
+ * Libbrasero-burn is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -185,8 +189,7 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		if (!cuepath)
 			return FALSE;
 
-		if (!strstr (line, cuepath)
-		&&  !strstr (line, "ERROR: Could not find input file")) {
+		if (!strstr (line, "ERROR: Could not find input file")) {
 			g_free (cuepath);
 			return FALSE;
 		}
@@ -203,7 +206,7 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		g_free (name);
 	}
 
-	return TRUE;
+	return FALSE;
 }
 
 static BraseroBurnResult
@@ -256,13 +259,11 @@ brasero_cdrdao_set_argv_device (BraseroCdrdao *cdrdao,
 
 	g_ptr_array_add (argv, g_strdup ("--device"));
 
-#ifdef HAVE_CAM_LIB_H
-	/* FreeBSD like that better */
+	/* NOTE: that function returns either bus_target_lun or the device path
+	 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+	 * which is the only OS in need for that. For all others it returns the device
+	 * path. */
 	brasero_job_get_bus_target_lun (BRASERO_JOB (cdrdao), &device);
-#else
-	brasero_job_get_device (BRASERO_JOB (cdrdao), &device);
-#endif
-
 	g_ptr_array_add (argv, device);
 }
 
@@ -342,13 +343,11 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 		brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
 		drive = brasero_track_disc_get_drive (BRASERO_TRACK_DISC (track));
 
-#ifdef HAVE_CAM_LIB_H
-	/* FreeBSD like that better */
+		/* NOTE: that function returns either bus_target_lun or the device path
+		 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+		 * which is the only OS in need for that. For all others it returns the device
+		 * path. */
 		g_ptr_array_add (argv, brasero_drive_get_bus_target_lun_string (drive));
-#else
-		g_ptr_array_add (argv, g_strdup (brasero_drive_get_device (drive)));
-#endif
-
 	}
 	else if (brasero_track_type_get_has_image (type)) {
 		gchar *cuepath;
@@ -444,13 +443,11 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 	brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
 	drive = brasero_track_disc_get_drive (BRASERO_TRACK_DISC (track));
 
-#ifdef HAVE_CAM_LIB_H
-	/* FreeBSD like that better */
+	/* NOTE: that function returns either bus_target_lun or the device path
+	 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+	 * which is the only OS in need for that. For all others it returns the device
+	 * path. */
 	g_ptr_array_add (argv, brasero_drive_get_bus_target_lun_string (drive));
-#else
-	g_ptr_array_add (argv, g_strdup (brasero_drive_get_device (drive)));
-#endif
-
 	g_ptr_array_add (argv, g_strdup ("--read-raw"));
 
 	/* This is done so that if a cue file is required we first generate
