@@ -202,7 +202,7 @@ brasero_dvdcss_write_sector_to_fd (BraseroDvdcss *self,
 		gint written;
 
 		written = write (fd,
-				 buffer + bytes_written,
+				 ((gchar *) buffer)  + bytes_written,
 				 bytes_remaining);
 
 		if (priv->cancel)
@@ -256,12 +256,12 @@ brasero_dvdcss_create_scrambled_sectors_map (GQueue *map,
 				BraseroScrambledSectorRange *range;
 				GSList *extents;
 
-				range = g_new0 (BraseroScrambledSectorRange, 1);
-
 				/* take the first address for each extent of the file */
 				if (!file->specific.file.extents)
 					return FALSE;
 
+				range = g_new0 (BraseroScrambledSectorRange, 1);
+				
 				for (extents = file->specific.file.extents; extents; extents = extents->next) {
 					BraseroVolFileExtent *extent;
 
@@ -427,8 +427,6 @@ brasero_dvdcss_write_image_thread (gpointer data)
 				num_blocks = range->start - written_sectors;
 		}
 		else {
-			int pos;
-
 			/* this is in a scrambled sectors range */
 			flag = DVDCSS_READ_DECRYPT;
 
