@@ -527,8 +527,8 @@ brasero_audio_disc_finalize (GObject *object)
 	
 	brasero_audio_disc_reset_real (cobj);
 
-	g_free (cobj->priv->add_dir);
-	g_free (cobj->priv->add_playlist);
+	brasero_io_job_base_free (cobj->priv->add_dir);
+	brasero_io_job_base_free (cobj->priv->add_playlist);
 	cobj->priv->add_dir = NULL;
 	cobj->priv->add_playlist = NULL;
 
@@ -782,9 +782,13 @@ brasero_audio_disc_unreadable_dialog (BraseroAudioDisc *disc,
 				      GError *error)
 {
 	gchar *primary;
-	gchar *name = NULL;
+	gchar *name;
+	GFile *file;
+
+	file = g_file_new_for_uri (uri);
+	name = g_file_get_basename (file);
+	g_object_unref (file);
 
-	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
 	primary = g_strdup_printf (_("\"%s\" could not be opened."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
@@ -907,7 +911,7 @@ brasero_audio_disc_add_uri (BraseroDisc *disc,
 	GtkTreePath *treepath = NULL;
 	BraseroAudioDisc *audio_disc;
 	BraseroDiscResult result;
-
+g_print ("RECEIVED\n");
 	audio_disc = BRASERO_AUDIO_DISC (disc);
 	result = brasero_audio_disc_add_uri_real (audio_disc,
 						  uri,
@@ -1515,8 +1519,8 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
         /* information about the track */
         gtk_tree_model_get_iter (model, &iter, treepath);
         gtk_tree_model_get (model, &iter,
-                                         BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
-                                         -1);
+                            BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
+                            -1);
         brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
 
 	/* set up dialog */
@@ -1557,9 +1561,9 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
 					   &gap);
 
 	brasero_track_stream_set_boundaries (BRASERO_TRACK_STREAM (track),
-                                                                      start,
-                                                                      end,
-                                                                      BRASERO_SECTORS_TO_TIME (gap));
+                                             start,
+                                             end,
+                                             gap);
 
 	if (title)
 		brasero_track_tag_add_string (BRASERO_TRACK (track),
