@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /***************************************************************************
  *            brasero-layout.c
  *
@@ -81,6 +83,8 @@ struct BraseroLayoutPrivate {
 	GtkWidget *project;
 
 	GtkWidget *combo;
+	GtkWidget *top_box;
+
 	BraseroLayoutType ctx_type;
 	BraseroLayoutItem *active_item;
 
@@ -750,6 +754,9 @@ brasero_layout_add_source (BraseroLayout *layout,
 			    ITEM_COL, item,
 			    VISIBLE_COL, TRUE,
 			    -1);
+
+	if (gtk_tree_model_iter_n_children (model, NULL) > 1)
+		gtk_widget_show (layout->priv->top_box);
 }
 
 /**************************** empty view callback ******************************/
@@ -795,9 +802,9 @@ brasero_layout_combo_changed_cb (GtkComboBox *combo,
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project), NULL);
 	}
 	else {
-		brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project),
 					    BRASERO_URI_CONTAINER (source));
+		brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 	}
 
 	brasero_layout_save (layout, item->id);
@@ -810,6 +817,7 @@ brasero_layout_item_set_visible (BraseroLayout *layout,
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+	guint num = 0;
 
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (layout->priv->combo));
 	model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
@@ -836,6 +844,23 @@ brasero_layout_item_set_visible (BraseroLayout *layout,
 		gtk_widget_show (item->widget);
 	else
 		gtk_widget_hide (item->widget);
+
+	gtk_tree_model_get_iter_first (model, &iter);
+	do {
+		gboolean visible;
+
+		gtk_tree_model_get (model, &iter,
+				    VISIBLE_COL, &visible,
+				    -1);
+
+		num += visible;
+	} while (gtk_tree_model_iter_next (model, &iter));
+
+
+	if (num > 1)
+		gtk_widget_show (layout->priv->top_box);
+	else
+		gtk_widget_hide (layout->priv->top_box);
 }
 
 void
@@ -1424,9 +1449,9 @@ brasero_layout_init (BraseroLayout *obj)
 							      NULL,
 							      NULL);
 
-	/* close button and  combo */
+	/* close button and combo. Don't show it now. */
 	box = gtk_hbox_new (FALSE, 6);
-	gtk_widget_show (box);
+	obj->priv->top_box = box;
 	gtk_box_pack_start (GTK_BOX (obj->priv->main_box),
 			    box,
 			    FALSE,
@@ -1481,7 +1506,6 @@ brasero_layout_init (BraseroLayout *obj)
 			  obj);
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
-
 	obj->priv->notebook = gtk_notebook_new ();
 	gtk_widget_show (obj->priv->notebook);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (obj->priv->notebook), FALSE);
