@@ -38,14 +38,15 @@
 #include <gconf/gconf-client.h>
 
 #include "brasero-misc.h"
+#include "brasero-metadata.h"
+#include "brasero-io.h"
 
-#include "burn-debug.h"
+#include "brasero-units.h"
 
 #include "brasero-player.h"
 #include "brasero-player-bacon.h"
 #include "brasero-utils.h"
-#include "brasero-metadata.h"
-#include "brasero-io.h"
+
 
 G_DEFINE_TYPE (BraseroPlayer, brasero_player, GTK_TYPE_ALIGNMENT);
 
@@ -80,7 +81,6 @@ struct BraseroPlayerPrivate {
 
 	BraseroPlayerBaconState state;
 
-	BraseroIO *io;
 	BraseroIOJobBase *meta_task;
 
 	gchar *uri;
@@ -285,8 +285,7 @@ brasero_player_range_value_changed (GtkRange *range,
 
 		/* user changed the value tell the player/pipeline */
 		pos = gtk_range_get_value (GTK_RANGE (player->priv->progress));
-		if(!brasero_player_bacon_set_pos (BRASERO_PLAYER_BACON (player->priv->bacon), (gint64) pos + player->priv->start))
-			BRASERO_BURN_LOG ("position in stream cannot be set");
+		brasero_player_bacon_set_pos (BRASERO_PLAYER_BACON (player->priv->bacon), (gint64) pos + player->priv->start);
 	}
 
 	brasero_player_update_position (player);
@@ -502,15 +501,14 @@ brasero_player_create_controls_stream (BraseroPlayer *player,
 				    0);
 
 		hbox = gtk_hbox_new (FALSE, 0);
-		alignment = gtk_alignment_new (1.0, 0.0, 0.0, 0.0);
-		player->priv->button = gtk_button_new ();
+
 		gtk_container_add (GTK_CONTAINER (alignment), hbox);
 		gtk_box_pack_start (GTK_BOX (box),
 				    alignment,
 				    TRUE,
 				    TRUE,
 				    0);
-
+		
 		image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_BUTTON);
 		zoom = gtk_button_new ();
 		gtk_button_set_image (GTK_BUTTON (zoom), image);
@@ -891,11 +889,18 @@ brasero_player_metadata_completed (GObject *obj,
 
 	/* based on the mime type, we try to determine the type of file */
 	if (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_VIDEO)) {
+		if (g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN) <= 0) {
+			brasero_player_no_multimedia_stream (player);
+			g_signal_emit (player,
+				       brasero_player_signals [ERROR_SIGNAL],
+				       0);
+			return;
+		}
+
 		/* video */
 		brasero_player_create_controls_stream (player, TRUE);
 		gtk_range_set_value (GTK_RANGE (player->priv->progress), 0.0);
-
-		if (g_file_info_get_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE))
+		if (g_file_info_get_attribute_boolean (info,BRASERO_IO_IS_SEEKABLE))
 			gtk_widget_set_sensitive (player->priv->progress, TRUE);
 		else
 			gtk_widget_set_sensitive (player->priv->progress, FALSE);
@@ -905,11 +910,18 @@ brasero_player_metadata_completed (GObject *obj,
 		gtk_widget_show (player->priv->notebook);
 	}
 	else if (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_AUDIO)) {
+		if (g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN) <= 0) {
+			brasero_player_no_multimedia_stream (player);
+			g_signal_emit (player,
+				       brasero_player_signals [ERROR_SIGNAL],
+				       0);
+			return;
+		}
+
 		/* audio */
 		brasero_player_create_controls_stream (player, FALSE);
 		gtk_widget_hide (player->priv->notebook);
 		gtk_range_set_value (GTK_RANGE (player->priv->progress), 0.0);
-
 		if (g_file_info_get_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE))
 			gtk_widget_set_sensitive (player->priv->progress, TRUE);
 		else
@@ -918,7 +930,7 @@ brasero_player_metadata_completed (GObject *obj,
 	else if (mime && !strncmp ("image/", mime, 6)) {
 		/* Only do that if the image is < 20 M otherwise that's crap
 		 * FIXME: maybe a sort of error message here? or use thumbnail? */
-		if (g_file_info_get_size (info) > 100000000) {
+		if (g_file_info_get_size (info) > 100000000LL) {
 			brasero_player_no_multimedia_stream (player);
 			g_signal_emit (player,
 				       brasero_player_signals [ERROR_SIGNAL],
@@ -956,17 +968,13 @@ brasero_player_metadata_completed (GObject *obj,
 static void
 brasero_player_retrieve_metadata (BraseroPlayer *player)
 {
-	if (!player->priv->io)
-		player->priv->io = brasero_io_get_default ();
-
 	if (!player->priv->meta_task)
 		player->priv->meta_task = brasero_io_register (G_OBJECT (player),
 							       brasero_player_metadata_completed,
 							       NULL,
 							       NULL);
 
-	brasero_io_get_file_info (player->priv->io,
-				  player->priv->uri,
+	brasero_io_get_file_info (player->priv->uri,
 				  player->priv->meta_task,
 				  BRASERO_IO_INFO_METADATA|
 				  BRASERO_IO_INFO_MIME,
@@ -1040,9 +1048,8 @@ brasero_player_set_uri (BraseroPlayer *player,
 	player->priv->start = 0;
 	player->priv->end = 0;
 
-	if (player->priv->io)
-		brasero_io_cancel_by_base (player->priv->io,
-					   player->priv->meta_task);
+	if (player->priv->meta_task)
+		brasero_io_cancel_by_base (player->priv->meta_task);
 
 	/* That stops the pipeline from playing */
 	brasero_player_bacon_set_uri (BRASERO_PLAYER_BACON (player->priv->bacon), NULL);
@@ -1109,7 +1116,7 @@ brasero_player_eof_cb (BraseroPlayerBacon *bacon, BraseroPlayer *player)
 	gtk_image_set_from_stock (GTK_IMAGE (player->priv->image),
 				  GTK_STOCK_MEDIA_PLAY,
 				  GTK_ICON_SIZE_BUTTON);
-	
+
 	if (player->priv->update_scale_id) {
 		g_source_remove (player->priv->update_scale_id);
 		player->priv->update_scale_id = 0;
@@ -1291,17 +1298,11 @@ brasero_player_destroy (GtkObject *obj)
 	}
 
 	if (player->priv->meta_task){
-		brasero_io_cancel_by_base (player->priv->io,
-					   player->priv->meta_task);
-		g_free (player->priv->meta_task);
+		brasero_io_cancel_by_base (player->priv->meta_task);
+		brasero_io_job_base_free (player->priv->meta_task);
 		player->priv->meta_task = 0;
 	}
 
-	if (player->priv->io) {
-		g_object_unref (player->priv->io);
-		player->priv->io = NULL;
-	}
-
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		GTK_OBJECT_CLASS (parent_class)->destroy (obj);
 }
