@@ -36,10 +36,15 @@
 
 #include <gst/gst.h>
 
+#include "brasero-units.h"
+
 #include "brasero-song-properties.h"
 #include "brasero-time-button.h"
-#include "brasero-utils.h"
-#include "burn-track.h"
+
+#include "brasero-misc.h"
+
+#include "brasero-track.h"
+#include "brasero-track-stream.h"
 
 G_DEFINE_TYPE (BraseroSongProps, brasero_song_props, GTK_TYPE_DIALOG);
 
@@ -75,7 +80,7 @@ brasero_song_props_update_length (BraseroSongProps *self)
 	start = brasero_time_button_get_value (BRASERO_TIME_BUTTON (self->priv->start));
 	gap = gtk_spin_button_get_value (GTK_SPIN_BUTTON (self->priv->gap)) * GST_SECOND;
 
-	length_str = brasero_units_get_time_string (BRASERO_AUDIO_TRACK_LENGTH (start, end + gap), TRUE, FALSE);
+	length_str = brasero_units_get_time_string (BRASERO_STREAM_LENGTH (start, end + gap), TRUE, FALSE);
 	gtk_label_set_markup (GTK_LABEL (self->priv->length), length_str);
 	g_free (length_str);
 }
@@ -111,7 +116,7 @@ brasero_song_props_gap_changed_cb (GtkSpinButton *button,
 	start = brasero_time_button_get_value (BRASERO_TIME_BUTTON (self->priv->start));
 	gap = gtk_spin_button_get_value (GTK_SPIN_BUTTON (self->priv->gap)) * GST_SECOND;
 
-	length_str = brasero_units_get_time_string (BRASERO_AUDIO_TRACK_LENGTH (start, end + gap), TRUE, FALSE);
+	length_str = brasero_units_get_time_string (BRASERO_STREAM_LENGTH (start, end + gap), TRUE, FALSE);
 	gtk_label_set_markup (GTK_LABEL (self->priv->length), length_str);
 	g_free (length_str);
 }
@@ -385,6 +390,7 @@ brasero_song_props_set_properties (BraseroSongProps *self,
 		gtk_entry_set_text (GTK_ENTRY (self->priv->title), title);
 	if (composer)
 		gtk_entry_set_text (GTK_ENTRY (self->priv->composer), composer);
+
 	if (isrc) {
 		string = g_strdup_printf ("%i", isrc);
 		gtk_entry_set_text (GTK_ENTRY (self->priv->isrc), string);
@@ -409,7 +415,7 @@ brasero_song_props_set_properties (BraseroSongProps *self,
 	brasero_time_button_set_max (BRASERO_TIME_BUTTON (self->priv->end), length);
 	brasero_time_button_set_value (BRASERO_TIME_BUTTON (self->priv->end), end);
 	g_signal_handlers_unblock_by_func (self->priv->end,
-					   brasero_song_props_end_changed_cb,
+	        			   brasero_song_props_end_changed_cb,
 					   self);
 
 	brasero_song_props_update_length (self);
