@@ -32,8 +32,6 @@
 
 #include <gtk/gtk.h>
 
-#include "burn-basics.h"
-
 G_BEGIN_DECLS
 
 #define BRASERO_TYPE_SONG_PROPS         (brasero_song_props_get_type ())
@@ -78,4 +76,6 @@ brasero_song_props_set_properties (BraseroSongProps *self,
 				   gint64 end,
 				   gint64 gap);
 
+G_END_DECLS
+
 #endif /* SONG_PROPERTIES_H */
