@@ -385,8 +385,12 @@ brasero_video_disc_unreadable_uri_dialog (BraseroVideoDisc *self,
 {
 	gchar *primary;
 	gchar *name;
+	GFile *file;
+
+	file = g_file_new_for_uri (uri);
+	name = g_file_get_basename (file);
+	g_object_unref (file);
 
-	name = g_filename_display_basename (uri);
 	primary = g_strdup_printf (_("\"%s\" could not be opened."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
@@ -459,7 +463,7 @@ brasero_video_disc_session_changed (BraseroSessionCfg *session,
 			error = brasero_status_get_error (status);
 			if (!error)
 				brasero_video_disc_unreadable_uri_dialog (self, uri, error);
-			else if (error->code != BRASERO_BURN_ERROR_FILE_FOLDER) {
+			else if (error->code == BRASERO_BURN_ERROR_FILE_FOLDER) {
 				res = brasero_video_disc_directory_dialog (self);
 				if (res)
 					brasero_video_disc_add_directory_contents (self, uri, BRASERO_TRACK (track));
@@ -1058,7 +1062,7 @@ brasero_video_disc_add_ui (BraseroDisc *disc,
 	g_object_ref (message);
 
 	if (!priv->disc_group) {
-		priv->disc_group = gtk_action_group_new (BRASERO_DISC_ACTION);
+		priv->disc_group = gtk_action_group_new (BRASERO_DISC_ACTION "-video");
 		gtk_action_group_set_translation_domain (priv->disc_group, GETTEXT_PACKAGE);
 		gtk_action_group_add_actions (priv->disc_group,
 					      entries,
@@ -1272,7 +1276,8 @@ brasero_video_disc_finalize (GObject *object)
 	priv = BRASERO_VIDEO_DISC_PRIVATE (object);
 
 	if (priv->load_dir) {
-		g_free (priv->load_dir);
+		brasero_io_cancel_by_base (priv->load_dir);
+		brasero_io_job_base_free (priv->load_dir);
 		priv->load_dir = NULL;
 	}	
 
