@@ -29,6 +29,8 @@
 
 #include <gtk/gtk.h>
 
+#include "brasero-units.h"
+
 #include "brasero-session-cfg.h"
 #include "brasero-tags.h"
 #include "brasero-track-stream-cfg.h"
@@ -173,11 +175,17 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 
 	if (GPOINTER_TO_INT (iter->user_data2) == BRASERO_STREAM_ROW_GAP) {
 		switch (column) {
+		case BRASERO_VIDEO_TREE_MODEL_WEIGHT:
+			g_value_init (value, PANGO_TYPE_STYLE);
+			g_value_set_enum (value, PANGO_WEIGHT_BOLD);
+			return;
+		case BRASERO_VIDEO_TREE_MODEL_STYLE:
+			g_value_init (value, PANGO_TYPE_STYLE);
+			g_value_set_enum (value, PANGO_STYLE_ITALIC);
+			return;
 		case BRASERO_VIDEO_TREE_MODEL_NAME:
-			text = g_strdup_printf ("<i><b>%s</b></i>", _("Pause"));
 			g_value_init (value, G_TYPE_STRING);
-			g_value_set_string (value, text);
-			g_free (text);
+			g_value_set_string (value, _("Pause"));
 			break;
 		case BRASERO_VIDEO_TREE_MODEL_ICON_NAME:
 			g_value_init (value, G_TYPE_STRING);
@@ -217,27 +225,36 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 	}
 
 	switch (column) {
+	case BRASERO_VIDEO_TREE_MODEL_WEIGHT:
+		g_value_init (value, PANGO_TYPE_STYLE);
+		g_value_set_enum (value, PANGO_WEIGHT_NORMAL);
+		return;
+	case BRASERO_VIDEO_TREE_MODEL_STYLE:
+		g_value_init (value, PANGO_TYPE_STYLE);
+		g_value_set_enum (value, PANGO_STYLE_NORMAL);
+		return;
 	case BRASERO_VIDEO_TREE_MODEL_NAME:
 		g_value_init (value, G_TYPE_STRING);
 
 		string = brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_TITLE_TAG);
-		if (string)
+		if (string) {
 			g_value_set_string (value, string);
+		}
 		else {
+			GFile *file;
 			gchar *uri;
 			gchar *name;
-			gchar *path;
 			gchar *unescaped;
 
 			uri = brasero_track_stream_get_source (BRASERO_TRACK_STREAM (track), TRUE);
 			unescaped = g_uri_unescape_string (uri, NULL);
 			g_free (uri);
 
-			path = g_filename_from_uri (unescaped, NULL, NULL);
+			file = g_file_new_for_uri (unescaped);
 			g_free (unescaped);
 
-			name = g_path_get_basename (path);
-			g_free (path);
+			name = g_file_get_basename (file);
+			g_object_unref (file);
 
 			g_value_set_string (value, name);
 			g_free (name);
@@ -249,7 +266,7 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 		g_value_init (value, G_TYPE_STRING);
 
 		string = brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_ARTIST_TAG);
-		if (string)
+		if (string) 
 			g_value_set_string (value, string);
 
 		return;
@@ -464,11 +481,12 @@ brasero_video_tree_model_path_to_track (BraseroVideoTreeModel *self,
 
 		index --;
 
-		if (index <= 0)
-			return BRASERO_TRACK (track);
+		if (brasero_track_stream_get_gap (track) > 0) {
+			if (index <= 0)
+				return BRASERO_TRACK (track);
 
-		if (brasero_track_stream_get_gap (track) > 0)
-			index --;
+				index --;
+		}
 	}
 
 	return NULL;
@@ -632,6 +650,12 @@ brasero_video_tree_model_get_column_type (GtkTreeModel *model,
 	case BRASERO_VIDEO_TREE_MODEL_IS_GAP:
 		return G_TYPE_STRING;
 
+	case BRASERO_VIDEO_TREE_MODEL_WEIGHT:
+		return PANGO_TYPE_WEIGHT;
+
+	case BRASERO_VIDEO_TREE_MODEL_STYLE:
+		return PANGO_TYPE_STYLE;
+
 	default:
 		break;
 	}
@@ -815,22 +839,25 @@ brasero_video_tree_model_drag_data_received (GtkTreeDragDest *drag_dest,
 
 	/* The new row(s) must be before dest_path but after our sibling */
 	sibling = brasero_video_tree_model_path_to_track (BRASERO_VIDEO_TREE_MODEL (drag_dest), dest_path);
-		
+
 	/* Received data: see where it comes from:
 	 * - from us, then that's a simple move
 	 * - from another widget then it's going to be URIS and we add
 	 *   them to VideoProject */
 	if (selection_data->target == gdk_atom_intern (BRASERO_DND_TARGET_SELF_FILE_NODES, TRUE)) {
 		BraseroDNDVideoContext *context;
+		GtkTreeRowReference *dest;
 		GList *iter;
 
 		context = (BraseroDNDVideoContext *) selection_data->data;
 		if (context->model != GTK_TREE_MODEL (drag_dest))
 			return TRUE;
 
+		dest = gtk_tree_row_reference_new (GTK_TREE_MODEL (drag_dest), dest_path);
 		/* That's us: move the row and its children. */
 		for (iter = context->references; iter; iter = iter->next) {
 			GtkTreeRowReference *reference;
+			GtkTreePath *destination;
 			GtkTreePath *treepath;
 			GtkTreeIter tree_iter;
 
@@ -841,23 +868,39 @@ brasero_video_tree_model_drag_data_received (GtkTreeDragDest *drag_dest,
 						 treepath);
 			gtk_tree_path_free (treepath);
 
+			destination = gtk_tree_row_reference_get_path (dest);
 			brasero_video_tree_model_move_before (BRASERO_VIDEO_TREE_MODEL (drag_dest),
 							      &tree_iter,
-							      dest_path);
+							      destination);
+			gtk_tree_path_free (destination);
 		}
+		gtk_tree_row_reference_free (dest);
 	}
 	else if (selection_data->target == gdk_atom_intern ("text/uri-list", TRUE)) {
 		gint i;
-		gchar **uris;
+		gchar **uris = NULL;
 		gboolean success = FALSE;
+		const guchar *selection_data_raw;
+
+		/* NOTE: for some reason gdk_text_property_to_utf8_list_for_display ()
+		 * fails with banshee DND URIs list when calling gtk_selection_data_get_uris ().
+		 * so do like nautilus */
 
 		/* NOTE: there can be many URIs at the same time. One
 		 * success is enough to return TRUE. */
-		success = FALSE;
+		selection_data_raw = gtk_selection_data_get_data (selection_data);
 		uris = gtk_selection_data_get_uris (selection_data);
+		if (!uris) {
+			const guchar *selection_data_raw;
+
+			selection_data_raw = gtk_selection_data_get_data (selection_data);
+			uris = g_uri_list_extract_uris ((gchar *) selection_data_raw);
+		}
+
 		if (!uris)
 			return TRUE;
 
+		success = FALSE;
 		for (i = 0; uris [i]; i ++) {
 			BraseroTrackStreamCfg *track;
 
